secrets

package
v0.3.34 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 26, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Ed25519SignMessage added in v0.3.34

func Ed25519SignMessage(message, privKeyPath string) (string, error)

Ed25519SignMessage generates a message signature using Ed25519

func Ed25519SignMessageWithKey added in v0.3.34

func Ed25519SignMessageWithKey(message string, privKey ed25519.PrivateKey) string

Ed25519SignMessageWithKey generates a message signature using the given Ed25519 private key

func Ed25519VerifySignature added in v0.3.34

func Ed25519VerifySignature(message, signature, pubKeyPath string) (bool, error)

Ed25519VerifySignature verifies a message signature using Ed25519

func Ed25519VerifySignatureWithKey added in v0.3.34

func Ed25519VerifySignatureWithKey(message, signature string, pubKey ed25519.PublicKey) (bool, error)

Ed25519VerifySignatureWithKey verifies a message signature using the given Ed25519 public key

func GenerateEd25519Keys added in v0.3.34

func GenerateEd25519Keys(pubKeyPath, privKeyPath string) error

GenerateEd25519Keys generates Ed25519 key pair and saves it to PEM files

func LoadEd25519PrivateKey added in v0.3.34

func LoadEd25519PrivateKey(path string) (ed25519.PrivateKey, error)

LoadEd25519PrivateKey loads Ed25519 private key from PEM file

func LoadEd25519PublicKey added in v0.3.34

func LoadEd25519PublicKey(path string) (ed25519.PublicKey, error)

LoadEd25519PublicKey loads Ed25519 public key from PEM file

func LoadEnv

func LoadEnv(path string) error

LoadEnv loads environment variables from given path

func LoadRequiredEnv

func LoadRequiredEnv(path string, requiredKeys []string) error

LoadRequiredEnv loads environment variables from given path and checks that all required keys are set

Types

This section is empty.

Jump to