Documentation
¶
Overview ¶
Package clock contains time and date-related functions
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HourMinFormat ¶
HourMinFormat formats the given time in hh:mm format
func TimestampFormat ¶
TimestampFormat formats the given time in timestamp format (yymmddhhmmss)
Types ¶
type Date ¶
type Date = string
func DateFormat ¶
DateFormat formats the given time in date format (yyyy-mm-dd)
type DateTime ¶
type DateTime = string
func DateTimeNow ¶
func DateTimeNow() DateTime
DateTimeNow returns the current datetime in standard format
func StandardFormat ¶
StandardFormat formats the given time in standard format (yyyy-mm-dd hh:mm:ss)
Click to show internal directories.
Click to hide internal directories.