package
Version:
v0.3.11
Opens a new window with list of versions in this module.
Published: Apr 8, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package daemon contains daemon types and functions
LoadConfig loads a Daemon Config which is expected to follow the required structure.
This checks if any Interval values are 0 (invalid).
type Instance[A any] struct {
}
NewInstance creates a new Daemon Instance
All returns info on all running daemons
Run runs a task every given interval, where TimeScale = time.Hour, time.Minute, time.Second
Source Files
¶
Click to show internal directories.
Click to hide internal directories.