Documentation
¶
Overview ¶
Package root contains root application functions
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Authenticate ¶
Authenticate performs authentication for the Root account in the command-line app
func NewCommandMap ¶
NewCommandMap creates a new map of command to CmdConfigs
Types ¶
type CmdConfig ¶
type CmdConfig struct {
Command string
MinParams int
Docs string
Handler CmdHandler
}
func NewCommand ¶
func NewCommand(command string, minParams int, docs string, handler CmdHandler) *CmdConfig
NewCommand creates a new CmdConfig
Click to show internal directories.
Click to hide internal directories.